@@ -254,11 +254,17 @@ static gboolean
 cal_date_on_today(CComponent* component,
 		  CalHomePlugin* desktop_plugin)
 {
-  //  struct tm* time = localtime(&t);
   struct tm time;
   time_t t = component->getDateStart();
-  time_get_remote(t, component->getTzid().c_str(), &time);
-
+  if(component->getType() == E_TODO ||
+     component->getAllDay())
+  {
+    time_get_remote(t, component->getTzid().c_str(), &time);
+  }
+  else
+  {
+    time_get_local_ex(t, &time);
+  }
   return time.tm_year == desktop_plugin->date_today.tm_year &&
     time.tm_mon == desktop_plugin->date_today.tm_mon &&
     time.tm_mday== desktop_plugin->date_today.tm_mday;
@@ -398,7 +404,15 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     char buf[255];
     //    struct tm* time = localtime(&event_start_time);
     struct tm time;
-    time_get_remote(event_start_time, (*event_iter)->getTzid().c_str(), &time);
+    if((*event_iter)->getType() == E_TODO ||
+       ((*event_iter)->getAllDay()))
+    {
+      time_get_remote(event_start_time, (*event_iter)->getTzid().c_str(), &time);
+    }
+    else
+    {
+      time_get_local_ex(event_start_time, &time);
+    }
 
     if((*event_iter)->getType() == E_TODO)
     {
